# Headings

Headings are used to structure the content of a document or webpage. The number of hash symbols (#) determines the level of the heading, with a single hash symbol (#) representing the highest level (heading 1), two hash symbols (##) representing the second level (heading 2), and so on.

### Header 1

    # Header 1

#### Example

# Header 1

### Header 2

    ## Header 2

#### Example

## Header 2

### Header 3

    ### Header 3

#### Example

### Header 3

### Header 4

    #### Header 4

#### Example

#### Header 4